@@ -386,6 +386,46 @@ def add_artifact(db: Database,
     return
 
 
+def remove_artifact(db: Database,
+                    id: int,
+                    name: str):
+    """Removes an artifact from an existing Sacred experiment with run ID.
+    Use with caution, there is no going back.
+
+    Args:
+        db: Database instance to query.
+
+        id: Run ID to remove artifact from.
+
+        name: Name of the artifact.
+    """
+    if id not in _get_run_ids(db):
+        raise ValueError(f"ID {id} not found in database.")
+
+    # Get artifacts already part of the experiment
+    query = {"_id": {"$in": [id]}}
+    res = db["runs"].find(query)
+    artifacts = res[0]['artifacts']
+
+    # Check if artifact name is in artifact list
+    artifact = [a for a in artifacts if a['name'] == name]
+    if len(artifact) == 0:
+        raise ValueError(f"Artifact {name} not found.")
+    elif len(artifact) > 1:
+        raise ValueError(f"More than one artifact found with name {name}.")
+    artifact = artifact[0]
+
+    # Remove associated GridFS entry
+    object_id = artifact['file_id']
+    data._delete_gridfs_data(db, object_id)
+
+    # Remove artifact from run entry
+    artifacts = [a for a in artifacts if a['name'] != name]
+    db["runs"].update_one(query, {"$set": {"artifacts": artifacts}})
+
+    return
+
+
 def get_metric(db: Database, id: int, metric: str) -> dict:
     """Get metric from a Sacred experiment ID.
 
